Crate zlayer_paths

Crate zlayer_paths 

Re-exports

pub use escalate::applescript_quote;
pub use escalate::root_command;
pub use escalate::run_as_root;
pub use escalate::shell_quote;
pub use escalate::EscalationError;
pub use escalate::RootCommand;

Modules

escalate
Privilege escalation that works with or without a controlling terminal.
safe_fs
Symlink-safe filesystem tree operations.

Structs

ZLayerDirs
Centralized filesystem path resolution for ZLayer.

Functions

default_admin_bearer_path
Convenience: ZLayerDirs::system_default().admin_bearer_path().
is_root
Returns true when the current process is running with superuser / Administrator privileges.
sanitize_digest
Sanitize an OCI digest into a single, filesystem-safe path component.