Re-exports
pub use escalate::applescript_quote;pub use escalate::root_command;pub use escalate::run_as_root;pub use escalate::shell_quote;pub use escalate::EscalationError;pub use escalate::RootCommand;
Modules
- escalate
- Privilege escalation that works with or without a controlling terminal.
- safe_fs
- Symlink-safe filesystem tree operations.
Structs
- ZLayer
Dirs - Centralized filesystem path resolution for ZLayer.
Functions
- default_
admin_ bearer_ path - Convenience:
ZLayerDirs::system_default().admin_bearer_path(). - is_root
- Returns
truewhen the current process is running with superuser / Administrator privileges. - sanitize_
digest - Sanitize an OCI digest into a single, filesystem-safe path component.