ZLayerDirs

Struct ZLayerDirs 

pub struct ZLayerDirs { /* private fields */ }
Centralized filesystem path resolution for ZLayer.

All ZLayer crates should use this instead of hardcoding paths.

Implementations

Source

impl ZLayerDirs

pub fn new(data_dir: impl Into<PathBuf>) -> Self

Create from an explicit data directory.

pub fn system_default() -> Self

Create using the platform default data directory.

pub fn default_data_dir() -> PathBuf

Platform-aware default data directory.

  • macOS: ~/.zlayer
  • Linux (root): /var/lib/zlayer
  • Linux (user): ~/.zlayer
  • Windows: %LOCALAPPDATA%\ZLayer or C:\ProgramData\ZLayer
pub fn default_run_dir() -> PathBuf

Default runtime directory.

  • Linux: /var/run/zlayer
  • macOS: {default_data_dir}/run
  • Windows: {default_data_dir}\run
pub fn default_log_dir() -> PathBuf

Default log directory.

  • Linux: /var/log/zlayer
  • macOS: {default_data_dir}/logs
  • Windows: {default_data_dir}\logs
pub fn default_socket_path() -> String

Default Unix socket path.

  • Linux: /var/run/zlayer.sock
  • macOS: {default_data_dir}/run/zlayer.sock
  • Windows: tcp://127.0.0.1:3669
pub fn data_dir(&self) -> &Path

Root data directory.

pub fn containers(&self) -> PathBuf

Container state directory ({data}/containers).

pub fn rootfs(&self) -> PathBuf

Unpacked image rootfs directory ({data}/rootfs).

pub fn bundles(&self) -> PathBuf

OCI bundle directory ({data}/bundles).

pub fn cache(&self) -> PathBuf

Image/blob cache directory ({data}/cache).

pub fn volumes(&self) -> PathBuf

Named volumes directory ({data}/volumes).

pub fn wasm(&self) -> PathBuf

WASM module cache directory ({data}/wasm).

pub fn wasm_compiled(&self) -> PathBuf

AOT-compiled WASM cache directory ({data}/wasm/compiled).

pub fn secrets(&self) -> PathBuf

Encrypted secrets store directory ({data}/secrets).

pub fn certs(&self) -> PathBuf

TLS certificate storage directory ({data}/certs).

pub fn raft(&self) -> PathBuf

Raft consensus data directory ({data}/raft).

pub fn admin_password(&self) -> PathBuf

Admin password file path ({data}/admin_password).

pub fn daemon_json(&self) -> PathBuf

Daemon metadata file path ({data}/daemon.json).

pub fn logs(&self) -> PathBuf

Logs subdirectory under data_dir ({data}/logs). Used on macOS where logs live under the user data dir.

pub fn vms(&self) -> PathBuf

macOS VM state directory ({data}/vms).

pub fn images(&self) -> PathBuf

OCI image storage directory ({data}/images).

pub fn bin(&self) -> PathBuf

Local binary directory ({data}/bin).

pub fn toolchain_cache(&self) -> PathBuf

Toolchain download cache directory ({data}/toolchain-cache).

pub fn tmp(&self) -> PathBuf

Temporary build directory ({data}/tmp).